# Table of Contents

- [sap-leanix-technology-risk-and-compliance](<./sap-leanix-technology-risk-and-compliance.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP LeanIX Technology Risk and Compliance](<./SAP-LeanIX-Technology-Risk-and-Compliance.md>)
  - [Overview](<./SAP-LeanIX-Technology-Risk-and-Compliance/Overview.md>)
  - [Detailed Guides](<./SAP-LeanIX-Technology-Risk-and-Compliance/Detailed-Guides.md>)
  - [Related Resources](<./SAP-LeanIX-Technology-Risk-and-Compliance/Related-Resources.md>)
